]> git.rkrishnan.org Git - pihpsdr.git/commitdiff
a) renamed "midi.inp" to "midi.props"
authorc vw <dl1ycf@darc.de>
Fri, 20 Dec 2019 15:42:21 +0000 (16:42 +0100)
committerc vw <dl1ycf@darc.de>
Fri, 20 Dec 2019 15:42:21 +0000 (16:42 +0100)
b) corrected "duplex" switching from toolbar and MIDI

Makefile.mac
discovery.c
ext.c
ext.h
midi2.c
midi3.c
radio_menu.c
radio_menu.h
toolbar.c

index 8b27c9c8b7b56276f632058c2f634692b4a349de..63f38933140c3032cd08f0835fbbeb3352446206 100644 (file)
@@ -539,7 +539,7 @@ hpsdrsim:       hpsdrsim.o newhpsdrsim.o
 #      $HOME -> Application Support -> piHPSDR
 #
 #       That is the directory where the WDSP wisdom file (created upon first
-#       start of piHPSDR) but also the radio settings and the midi.inp file
+#       start of piHPSDR) but also the radio settings and the midi.props file
 #       are stored.
 #
 #############################################################################
index 353c65e6be783816fd4624c10899ed8936080c29..d0829834aedaee0ac60c47c901e6307897ea788f 100644 (file)
@@ -103,7 +103,7 @@ static gboolean start_cb (GtkWidget *widget, GdkEventButton *event, gpointer dat
 #ifdef MIDI
 //
 // This is a file open dialog. If we choose a readable file here, it is just copied
-// to file "midi.inp" in the local directory
+// to file "midi.props" in the local directory
 //
 static gboolean midi_cb(GtkWidget *widget, GdkEventButton *event, gpointer data) {
     GtkWidget *opfile,*message;
@@ -135,7 +135,7 @@ static gboolean midi_cb(GtkWidget *widget, GdkEventButton *event, gpointer data)
         len=statbuf.st_size;
         //
         // Now first read the whole contents of the file, and then write it out.
-        // This is for new-bees trying to import the midi.inp in the working dir
+        // This is for new-bees trying to import the midi.props in the working dir
         //
         contents=g_new(char, len);
         bytes_read = bytes_written = 0;
@@ -148,8 +148,8 @@ static gboolean midi_cb(GtkWidget *widget, GdkEventButton *event, gpointer data)
       if (contents && bytes_read == len) {
        // should this file exist as a link or symlink, or should it
        // be read-only, remove it first
-       unlink("midi.inp");
-        fdout=open("midi.inp", O_WRONLY | O_CREAT, 0644);
+       unlink("midi.props");
+        fdout=open("midi.props", O_WRONLY | O_CREAT, 0644);
         if (fdout >= 0) {
           bytes_written=write(fdout, contents, len);
           close(fdout);
diff --git a/ext.c b/ext.c
index 0436735787a81dd4d243d5e73c8b5ff181e1e260..57a3e258ee8448a4e398e4a82ebaba5671570819 100644 (file)
--- a/ext.c
+++ b/ext.c
@@ -30,6 +30,7 @@
 #include "diversity_menu.h"
 #include "vfo.h"
 #include "radio.h"
+#include "radio_menu.h"
 #include "new_menu.h"
 #include "new_protocol.h"
 #ifdef PURESIGNAL
@@ -617,3 +618,8 @@ int ext_update_noise(void *data) {
   update_noise();
   return 0;
 }
+
+int ext_set_duplex(void *data) {
+  setDuplex();
+  return 0;
+}
diff --git a/ext.h b/ext.h
index 6fe1858ffacc253c9168396330752e18185c9b50..f70c958ee0227b698a03525794c590ef19bc74a8 100644 (file)
--- a/ext.h
+++ b/ext.h
@@ -106,5 +106,6 @@ int ext_start_tx(void *data);
 int ext_diversity_update(void *data);
 int ext_sat_update(void *data);
 int ext_set_rf_gain(void *data);
+int ext_set_duplex(void *data);
 
 int ext_update_noise(void *data);
diff --git a/midi3.c b/midi3.c
index 505ea0d67cc1c3b1740aae675bb655f0e3c5f824..b44947bd7530b58f3ce6f1643ed2ecceb91c4177 100644 (file)
--- a/midi3.c
+++ b/midi3.c
@@ -34,7 +34,7 @@ void DoTheMidi(enum MIDIaction action, enum MIDItype type, int val) {
     int    *ip;
 
     //
-    // Handle cases in alphabetical order of the key words in midi.inp
+    // Handle cases in alphabetical order of the key words in midi.props
     //
     switch (action) {
        /////////////////////////////////////////////////////////// "A2B"
@@ -234,12 +234,10 @@ void DoTheMidi(enum MIDIaction action, enum MIDItype type, int val) {
            break;
        /////////////////////////////////////////////////////////// "DUP"
         case MIDI_DUP:
-            if(duplex) {
-              duplex=0;
-            } else {
-              duplex=1;
-            }
-            g_idle_add(ext_vfo_update, NULL);
+           if (can_transmit) {
+             duplex=duplex==1?0:1;
+              g_idle_add(ext_set_duplex, NULL);
+           }
             break;
        /////////////////////////////////////////////////////////// "FILTERDOWN"
        /////////////////////////////////////////////////////////// "FILTERUP"
@@ -331,7 +329,7 @@ void DoTheMidi(enum MIDIaction action, enum MIDItype type, int val) {
            break;
        /////////////////////////////////////////////////////////// "MOX"
        case MIDI_MOX: // only key supported
-           if (type == MIDI_KEY) {
+           if (type == MIDI_KEY && can_transmit) {
                new = !mox;
                g_idle_add(ext_mox_update, GINT_TO_POINTER(new));
            }
@@ -613,7 +611,7 @@ void DoTheMidi(enum MIDIaction action, enum MIDItype type, int val) {
            break;    
        /////////////////////////////////////////////////////////// "TUNE"
        case MIDI_TUNE: // only key supported
-           if (type == MIDI_KEY) {
+           if (type == MIDI_KEY && can_transmit) {
                new = !tune;
                g_idle_add(ext_tune_update, GINT_TO_POINTER(new));
            }
index 71fc7cca89c93e8af8c93a77d4936107724ef456..e982f1e6e7c90888783b615d0e23aca7080ad3dd 100644 (file)
@@ -196,8 +196,10 @@ static void split_cb(GtkWidget *widget, gpointer data) {
   vfo_update();
 }
 
-static void duplex_cb(GtkWidget *widget, gpointer data) {
-  duplex=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
+//
+// call-able from outside, e.g. toolbar or MIDI
+//
+void setDuplex() {
   if(duplex) {
     gtk_container_remove(GTK_CONTAINER(fixed),transmitter->panel);
     reconfigure_transmitter(transmitter,display_width/4,display_height/2);
@@ -211,6 +213,11 @@ static void duplex_cb(GtkWidget *widget, gpointer data) {
   vfo_update();
 }
 
+static void duplex_cb(GtkWidget *widget, gpointer data) {
+  duplex=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
+  setDuplex();
+}
+
 static void sat_cb(GtkWidget *widget, gpointer data) {
   sat_mode=gtk_combo_box_get_active(GTK_COMBO_BOX(widget));
   vfo_update();
index bd4381241f7dbddf36ec67b01f90d530366d6ec7..7af7eab4f678fc0c0377a9ed901c95bbca317d60 100644 (file)
@@ -18,3 +18,4 @@
 */
 
 extern void radio_menu(GtkWidget *parent);
+extern void setDuplex(void);
index 591faddd00f7fa48387dea5446583c48daaf96c5..e05648b553c455e34007c2ecba102afe933e3a85 100644 (file)
--- a/toolbar.c
+++ b/toolbar.c
@@ -289,8 +289,8 @@ static void split_cb (GtkWidget *widget, gpointer data) {
 
 static void duplex_cb (GtkWidget *widget, gpointer data) {
   if(can_transmit) {
-    duplex=duplex==1?0:1;
-    g_idle_add(ext_vfo_update,NULL);
+    duplex=(duplex==1)?0:1;
+    g_idle_add(ext_set_duplex,NULL);
   }
 }
diff --git a/midi2.c b/midi2.c
index b698336e30e888a76f6173505426821de2872c9d..29788e2839f937ecd5a21c9d3e297b70aadabc55 100644 (file)
--- a/midi2.c
+++ b/midi2.c
@@ -90,7 +90,7 @@ void NewMidiEvent(enum MIDIevent event, int channel, int note, int val) {
 }
 
 /*
* This data structre connects names as used in the midi.inp file with
  * our MIDIaction enum values.
  * Take care that no key word is contained in another one!
  * Example: use "CURRVFO" not "VFO" otherwise there is possibly
@@ -152,7 +152,7 @@ static struct {
 };
 
 /*
* Translation from keyword in midi.inp file to MIDIaction
  */
 
 static enum MIDIaction keyword2action(char *s) {
@@ -188,7 +188,7 @@ void MIDIstartup() {
     for (i=0; i<128; i++) MidiCommandsTable.desc[i]=NULL;
     MidiCommandsTable.pitch=NULL;
 
-    fpin=fopen("midi.inp", "r");
+    fpin=fopen("midi.props", "r");
     if (!fpin) return;
 
     for (;;) {
@@ -90,7 +90,7 @@ void NewMidiEvent(enum MIDIevent event, int channel, int note, int val) {
 
 /*
- * This data structre connects names as used in the midi.inp file with
+ * This data structre connects names as used in the midi.props file with
  * our MIDIaction enum values.
  * Take care that no key word is contained in another one!
@@ -152,7 +152,7 @@ static struct {
 
 /*
- * Translation from keyword in midi.inp file to MIDIaction
+ * Translation from keyword in midi.props file to MIDIaction
  */
 